#include "LuaGlobals.h"
#include "../../core/scripts/LuaGlobalBridge.h"
#include "../../core/utils/Logging.h"
#include "../../core/utils/EngineConfig.h"
#include <imgui.h>

void DrawImGuiWindow()
{
    if (!g_engineConfig.settings.show_lua_globals_window)
        return;

    auto allGlobals = LuaGlobalBridge::GetAll();

    ImGui::Begin("Lua Globals");

    if (allGlobals.empty())
    {
        ImGui::TextDisabled("No global variables set.");
    }
    else
    {
        ImGui::Text("Active Globals:");
        ImGui::Separator();

        ImGui::Columns(2, nullptr, false);
        ImGui::SetColumnWidth(0, 160);

        ImGui::TextColored(ImVec4(1, 1, 0.4f, 1), "Key");
        ImGui::NextColumn();
        ImGui::TextColored(ImVec4(1, 1, 0.4f, 1), "Value");
        ImGui::NextColumn();
        ImGui::Separator();

        for (const auto& [key, value] : allGlobals)
        {
            std::string valueStr;

            std::visit([&](auto&& val) {
                using T = std::decay_t<decltype(val)>;
                if constexpr (std::is_same_v<T, double>)
                    valueStr = std::to_string(val);
                else if constexpr (std::is_same_v<T, bool>)
                    valueStr = val ? "true" : "false";
                else if constexpr (std::is_same_v<T, std::string>)
                    valueStr = val;
            }, value);

            ImGui::TextUnformatted(key.c_str());
            ImGui::NextColumn();
            ImGui::TextUnformatted(valueStr.c_str());
            ImGui::NextColumn();
        }

        ImGui::Columns(1);
    }

    ImGui::End();
}
